# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: auth.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from . import annotations_pb2 as annotations__pb2
from . import api_pb2 as api__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='auth.proto',
  package='org.couchers.auth',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\nauth.proto\x12\x11org.couchers.auth\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x11\x61nnotations.proto\x1a\tapi.proto\"\x9d\x02\n\rSignupFlowReq\x12\x18\n\nflow_token\x18\x01 \x01(\tB\x04\x80\xb5\x18\x01\x12-\n\x05\x62\x61sic\x18\x02 \x01(\x0b\x32\x1e.org.couchers.auth.SignupBasic\x12\x31\n\x07\x61\x63\x63ount\x18\x03 \x01(\x0b\x32 .org.couchers.auth.SignupAccount\x12\x34\n\x08\x66\x65\x65\x64\x62\x61\x63k\x18\x04 \x01(\x0b\x32\".org.couchers.auth.ContributorForm\x12\x19\n\x0b\x65mail_token\x18\x05 \x01(\tB\x04\x80\xb5\x18\x01\x12?\n\x1b\x61\x63\x63\x65pt_community_guidelines\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"\xdd\x01\n\rSignupFlowRes\x12\x18\n\nflow_token\x18\x01 \x01(\tB\x04\x80\xb5\x18\x01\x12,\n\x08\x61uth_res\x18\x03 \x01(\x0b\x32\x1a.org.couchers.auth.AuthRes\x12\x12\n\nneed_basic\x18\x04 \x01(\x08\x12\x14\n\x0cneed_account\x18\x05 \x01(\x08\x12\x15\n\rneed_feedback\x18\x06 \x01(\x08\x12\x19\n\x11need_verify_email\x18\x07 \x01(\x08\x12(\n need_accept_community_guidelines\x18\x08 \x01(\x08\"*\n\x0bSignupBasic\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t\"0\n\x12SignupTokenInfoReq\x12\x1a\n\x0csignup_token\x18\x01 \x01(\tB\x04\x80\xb5\x18\x01\"\xe6\x01\n\rSignupAccount\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x16\n\x08password\x18\x02 \x01(\tB\x04\x80\xb5\x18\x01\x12\x0c\n\x04\x63ity\x18\x06 \x01(\t\x12\x0b\n\x03lat\x18\x07 \x01(\x01\x12\x0b\n\x03lng\x18\x08 \x01(\x01\x12\x0e\n\x06radius\x18\t \x01(\x01\x12\x11\n\tbirthdate\x18\x03 \x01(\t\x12\x0e\n\x06gender\x18\x04 \x01(\t\x12<\n\x0ehosting_status\x18\x05 \x01(\x0e\x32$.org.couchers.api.core.HostingStatus\x12\x12\n\naccept_tos\x18\n \x01(\x08\"$\n\x10UsernameValidReq\x12\x10\n\x08username\x18\x01 \x01(\t\"!\n\x10UsernameValidRes\x12\r\n\x05valid\x18\x01 \x01(\x08\"\x18\n\x08LoginReq\x12\x0c\n\x04user\x18\x01 \x01(\t\"z\n\x08LoginRes\x12\x38\n\tnext_step\x18\x01 \x01(\x0e\x32%.org.couchers.auth.LoginRes.LoginStep\"4\n\tLoginStep\x12\x11\n\rNEED_PASSWORD\x10\x00\x12\x14\n\x10SENT_LOGIN_EMAIL\x10\x01\"2\n\x15\x43ompleteTokenLoginReq\x12\x19\n\x0blogin_token\x18\x01 \x01(\tB\x04\x80\xb5\x18\x01\"H\n\x07\x41uthReq\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x16\n\x08password\x18\x02 \x01(\tB\x04\x80\xb5\x18\x01\x12\x17\n\x0fremember_device\x18\x03 \x01(\x08\"*\n\x07\x41uthRes\x12\x0f\n\x07user_id\x18\x01 \x01(\x03\x12\x0e\n\x06jailed\x18\x02 \x01(\x08\" \n\x10ResetPasswordReq\x12\x0c\n\x04user\x18\x01 \x01(\t\">\n\x18\x43ompletePasswordResetReq\x12\"\n\x14password_reset_token\x18\x01 \x01(\tB\x04\x80\xb5\x18\x01\"9\n\x15\x43onfirmChangeEmailReq\x12 \n\x12\x63hange_email_token\x18\x01 \x01(\tB\x04\x80\xb5\x18\x01\"Q\n\x15\x43onfirmChangeEmailRes\x12\x38\n\x05state\x18\x01 \x01(\x0e\x32).org.couchers.auth.EmailConfirmationState\"\xab\x01\n\x0f\x43ontributorForm\x12\r\n\x05ideas\x18\x01 \x01(\t\x12\x10\n\x08\x66\x65\x61tures\x18\x02 \x01(\t\x12\x12\n\nexperience\x18\x03 \x01(\t\x12\x37\n\ncontribute\x18\x04 \x01(\x0e\x32#.org.couchers.auth.ContributeOption\x12\x17\n\x0f\x63ontribute_ways\x18\x05 \x03(\t\x12\x11\n\texpertise\x18\x06 \x01(\t*\xea\x01\n\x16\x45mailConfirmationState\x12$\n EMAIL_CONFIRMATION_STATE_UNKNOWN\x10\x00\x12$\n EMAIL_CONFIRMATION_STATE_SUCCESS\x10\x01\x12\x41\n=EMAIL_CONFIRMATION_STATE_REQUIRES_CONFIRMATION_FROM_OLD_EMAIL\x10\x02\x12\x41\n=EMAIL_CONFIRMATION_STATE_REQUIRES_CONFIRMATION_FROM_NEW_EMAIL\x10\x03*\x87\x01\n\x10\x43ontributeOption\x12!\n\x1d\x43ONTRIBUTE_OPTION_UNSPECIFIED\x10\x00\x12\x19\n\x15\x43ONTRIBUTE_OPTION_YES\x10\x01\x12\x1b\n\x17\x43ONTRIBUTE_OPTION_MAYBE\x10\x02\x12\x18\n\x14\x43ONTRIBUTE_OPTION_NO\x10\x03\x32\xa1\x06\n\x04\x41uth\x12i\n\nSignupFlow\x12 .org.couchers.auth.SignupFlowReq\x1a .org.couchers.auth.SignupFlowRes\"\x17\x82\xd3\xe4\x93\x02\x11\"\x0c/auth/signup:\x01*\x12[\n\rUsernameValid\x12#.org.couchers.auth.UsernameValidReq\x1a#.org.couchers.auth.UsernameValidRes\"\x00\x12\x43\n\x05Login\x12\x1b.org.couchers.auth.LoginReq\x1a\x1b.org.couchers.auth.LoginRes\"\x00\x12\\\n\x12\x43ompleteTokenLogin\x12(.org.couchers.auth.CompleteTokenLoginReq\x1a\x1a.org.couchers.auth.AuthRes\"\x00\x12H\n\x0c\x41uthenticate\x12\x1a.org.couchers.auth.AuthReq\x1a\x1a.org.couchers.auth.AuthRes\"\x00\x12\x42\n\x0e\x44\x65\x61uthenticate\x12\x16.google.protobuf.Empty\x1a\x16.google.protobuf.Empty\"\x00\x12N\n\rResetPassword\x12#.org.couchers.auth.ResetPasswordReq\x1a\x16.google.protobuf.Empty\"\x00\x12^\n\x15\x43ompletePasswordReset\x12+.org.couchers.auth.CompletePasswordResetReq\x1a\x16.google.protobuf.Empty\"\x00\x12j\n\x12\x43onfirmChangeEmail\x12(.org.couchers.auth.ConfirmChangeEmailReq\x1a(.org.couchers.auth.ConfirmChangeEmailRes\"\x00\x1a\x04\x88\xb5\x18\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,annotations__pb2.DESCRIPTOR,api__pb2.DESCRIPTOR,])

_EMAILCONFIRMATIONSTATE = _descriptor.EnumDescriptor(
  name='EmailConfirmationState',
  full_name='org.couchers.auth.EmailConfirmationState',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EMAIL_CONFIRMATION_STATE_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EMAIL_CONFIRMATION_STATE_SUCCESS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EMAIL_CONFIRMATION_STATE_REQUIRES_CONFIRMATION_FROM_OLD_EMAIL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EMAIL_CONFIRMATION_STATE_REQUIRES_CONFIRMATION_FROM_NEW_EMAIL', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1801,
  serialized_end=2035,
)
_sym_db.RegisterEnumDescriptor(_EMAILCONFIRMATIONSTATE)

EmailConfirmationState = enum_type_wrapper.EnumTypeWrapper(_EMAILCONFIRMATIONSTATE)
_CONTRIBUTEOPTION = _descriptor.EnumDescriptor(
  name='ContributeOption',
  full_name='org.couchers.auth.ContributeOption',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CONTRIBUTE_OPTION_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONTRIBUTE_OPTION_YES', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONTRIBUTE_OPTION_MAYBE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONTRIBUTE_OPTION_NO', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2038,
  serialized_end=2173,
)
_sym_db.RegisterEnumDescriptor(_CONTRIBUTEOPTION)

ContributeOption = enum_type_wrapper.EnumTypeWrapper(_CONTRIBUTEOPTION)
EMAIL_CONFIRMATION_STATE_UNKNOWN = 0
EMAIL_CONFIRMATION_STATE_SUCCESS = 1
EMAIL_CONFIRMATION_STATE_REQUIRES_CONFIRMATION_FROM_OLD_EMAIL = 2
EMAIL_CONFIRMATION_STATE_REQUIRES_CONFIRMATION_FROM_NEW_EMAIL = 3
CONTRIBUTE_OPTION_UNSPECIFIED = 0
CONTRIBUTE_OPTION_YES = 1
CONTRIBUTE_OPTION_MAYBE = 2
CONTRIBUTE_OPTION_NO = 3


_LOGINRES_LOGINSTEP = _descriptor.EnumDescriptor(
  name='LoginStep',
  full_name='org.couchers.auth.LoginRes.LoginStep',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NEED_PASSWORD', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SENT_LOGIN_EMAIL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1162,
  serialized_end=1214,
)
_sym_db.RegisterEnumDescriptor(_LOGINRES_LOGINSTEP)


_SIGNUPFLOWREQ = _descriptor.Descriptor(
  name='SignupFlowReq',
  full_name='org.couchers.auth.SignupFlowReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='flow_token', full_name='org.couchers.auth.SignupFlowReq.flow_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\200\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='basic', full_name='org.couchers.auth.SignupFlowReq.basic', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='account', full_name='org.couchers.auth.SignupFlowReq.account', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feedback', full_name='org.couchers.auth.SignupFlowReq.feedback', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='email_token', full_name='org.couchers.auth.SignupFlowReq.email_token', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\200\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accept_community_guidelines', full_name='org.couchers.auth.SignupFlowReq.accept_community_guidelines', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=155,
  serialized_end=440,
)


_SIGNUPFLOWRES = _descriptor.Descriptor(
  name='SignupFlowRes',
  full_name='org.couchers.auth.SignupFlowRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='flow_token', full_name='org.couchers.auth.SignupFlowRes.flow_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\200\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auth_res', full_name='org.couchers.auth.SignupFlowRes.auth_res', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='need_basic', full_name='org.couchers.auth.SignupFlowRes.need_basic', index=2,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='need_account', full_name='org.couchers.auth.SignupFlowRes.need_account', index=3,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='need_feedback', full_name='org.couchers.auth.SignupFlowRes.need_feedback', index=4,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='need_verify_email', full_name='org.couchers.auth.SignupFlowRes.need_verify_email', index=5,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='need_accept_community_guidelines', full_name='org.couchers.auth.SignupFlowRes.need_accept_community_guidelines', index=6,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=443,
  serialized_end=664,
)


_SIGNUPBASIC = _descriptor.Descriptor(
  name='SignupBasic',
  full_name='org.couchers.auth.SignupBasic',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='org.couchers.auth.SignupBasic.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='email', full_name='org.couchers.auth.SignupBasic.email', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=666,
  serialized_end=708,
)


_SIGNUPTOKENINFOREQ = _descriptor.Descriptor(
  name='SignupTokenInfoReq',
  full_name='org.couchers.auth.SignupTokenInfoReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='signup_token', full_name='org.couchers.auth.SignupTokenInfoReq.signup_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\200\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=710,
  serialized_end=758,
)


_SIGNUPACCOUNT = _descriptor.Descriptor(
  name='SignupAccount',
  full_name='org.couchers.auth.SignupAccount',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='username', full_name='org.couchers.auth.SignupAccount.username', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='org.couchers.auth.SignupAccount.password', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\200\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='city', full_name='org.couchers.auth.SignupAccount.city', index=2,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lat', full_name='org.couchers.auth.SignupAccount.lat', index=3,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lng', full_name='org.couchers.auth.SignupAccount.lng', index=4,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='radius', full_name='org.couchers.auth.SignupAccount.radius', index=5,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='birthdate', full_name='org.couchers.auth.SignupAccount.birthdate', index=6,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gender', full_name='org.couchers.auth.SignupAccount.gender', index=7,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hosting_status', full_name='org.couchers.auth.SignupAccount.hosting_status', index=8,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accept_tos', full_name='org.couchers.auth.SignupAccount.accept_tos', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=761,
  serialized_end=991,
)


_USERNAMEVALIDREQ = _descriptor.Descriptor(
  name='UsernameValidReq',
  full_name='org.couchers.auth.UsernameValidReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='username', full_name='org.couchers.auth.UsernameValidReq.username', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=993,
  serialized_end=1029,
)


_USERNAMEVALIDRES = _descriptor.Descriptor(
  name='UsernameValidRes',
  full_name='org.couchers.auth.UsernameValidRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='valid', full_name='org.couchers.auth.UsernameValidRes.valid', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1031,
  serialized_end=1064,
)


_LOGINREQ = _descriptor.Descriptor(
  name='LoginReq',
  full_name='org.couchers.auth.LoginReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='org.couchers.auth.LoginReq.user', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1066,
  serialized_end=1090,
)


_LOGINRES = _descriptor.Descriptor(
  name='LoginRes',
  full_name='org.couchers.auth.LoginRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='next_step', full_name='org.couchers.auth.LoginRes.next_step', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _LOGINRES_LOGINSTEP,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1092,
  serialized_end=1214,
)


_COMPLETETOKENLOGINREQ = _descriptor.Descriptor(
  name='CompleteTokenLoginReq',
  full_name='org.couchers.auth.CompleteTokenLoginReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='login_token', full_name='org.couchers.auth.CompleteTokenLoginReq.login_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\200\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1216,
  serialized_end=1266,
)


_AUTHREQ = _descriptor.Descriptor(
  name='AuthReq',
  full_name='org.couchers.auth.AuthReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='org.couchers.auth.AuthReq.user', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='org.couchers.auth.AuthReq.password', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\200\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remember_device', full_name='org.couchers.auth.AuthReq.remember_device', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1268,
  serialized_end=1340,
)


_AUTHRES = _descriptor.Descriptor(
  name='AuthRes',
  full_name='org.couchers.auth.AuthRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='org.couchers.auth.AuthRes.user_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jailed', full_name='org.couchers.auth.AuthRes.jailed', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1342,
  serialized_end=1384,
)


_RESETPASSWORDREQ = _descriptor.Descriptor(
  name='ResetPasswordReq',
  full_name='org.couchers.auth.ResetPasswordReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='org.couchers.auth.ResetPasswordReq.user', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1386,
  serialized_end=1418,
)


_COMPLETEPASSWORDRESETREQ = _descriptor.Descriptor(
  name='CompletePasswordResetReq',
  full_name='org.couchers.auth.CompletePasswordResetReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='password_reset_token', full_name='org.couchers.auth.CompletePasswordResetReq.password_reset_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\200\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1420,
  serialized_end=1482,
)


_CONFIRMCHANGEEMAILREQ = _descriptor.Descriptor(
  name='ConfirmChangeEmailReq',
  full_name='org.couchers.auth.ConfirmChangeEmailReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_email_token', full_name='org.couchers.auth.ConfirmChangeEmailReq.change_email_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\200\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1484,
  serialized_end=1541,
)


_CONFIRMCHANGEEMAILRES = _descriptor.Descriptor(
  name='ConfirmChangeEmailRes',
  full_name='org.couchers.auth.ConfirmChangeEmailRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='org.couchers.auth.ConfirmChangeEmailRes.state', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1543,
  serialized_end=1624,
)


_CONTRIBUTORFORM = _descriptor.Descriptor(
  name='ContributorForm',
  full_name='org.couchers.auth.ContributorForm',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ideas', full_name='org.couchers.auth.ContributorForm.ideas', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='features', full_name='org.couchers.auth.ContributorForm.features', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='experience', full_name='org.couchers.auth.ContributorForm.experience', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contribute', full_name='org.couchers.auth.ContributorForm.contribute', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contribute_ways', full_name='org.couchers.auth.ContributorForm.contribute_ways', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expertise', full_name='org.couchers.auth.ContributorForm.expertise', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1627,
  serialized_end=1798,
)

_SIGNUPFLOWREQ.fields_by_name['basic'].message_type = _SIGNUPBASIC
_SIGNUPFLOWREQ.fields_by_name['account'].message_type = _SIGNUPACCOUNT
_SIGNUPFLOWREQ.fields_by_name['feedback'].message_type = _CONTRIBUTORFORM
_SIGNUPFLOWREQ.fields_by_name['accept_community_guidelines'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_SIGNUPFLOWRES.fields_by_name['auth_res'].message_type = _AUTHRES
_SIGNUPACCOUNT.fields_by_name['hosting_status'].enum_type = api__pb2._HOSTINGSTATUS
_LOGINRES.fields_by_name['next_step'].enum_type = _LOGINRES_LOGINSTEP
_LOGINRES_LOGINSTEP.containing_type = _LOGINRES
_CONFIRMCHANGEEMAILRES.fields_by_name['state'].enum_type = _EMAILCONFIRMATIONSTATE
_CONTRIBUTORFORM.fields_by_name['contribute'].enum_type = _CONTRIBUTEOPTION
DESCRIPTOR.message_types_by_name['SignupFlowReq'] = _SIGNUPFLOWREQ
DESCRIPTOR.message_types_by_name['SignupFlowRes'] = _SIGNUPFLOWRES
DESCRIPTOR.message_types_by_name['SignupBasic'] = _SIGNUPBASIC
DESCRIPTOR.message_types_by_name['SignupTokenInfoReq'] = _SIGNUPTOKENINFOREQ
DESCRIPTOR.message_types_by_name['SignupAccount'] = _SIGNUPACCOUNT
DESCRIPTOR.message_types_by_name['UsernameValidReq'] = _USERNAMEVALIDREQ
DESCRIPTOR.message_types_by_name['UsernameValidRes'] = _USERNAMEVALIDRES
DESCRIPTOR.message_types_by_name['LoginReq'] = _LOGINREQ
DESCRIPTOR.message_types_by_name['LoginRes'] = _LOGINRES
DESCRIPTOR.message_types_by_name['CompleteTokenLoginReq'] = _COMPLETETOKENLOGINREQ
DESCRIPTOR.message_types_by_name['AuthReq'] = _AUTHREQ
DESCRIPTOR.message_types_by_name['AuthRes'] = _AUTHRES
DESCRIPTOR.message_types_by_name['ResetPasswordReq'] = _RESETPASSWORDREQ
DESCRIPTOR.message_types_by_name['CompletePasswordResetReq'] = _COMPLETEPASSWORDRESETREQ
DESCRIPTOR.message_types_by_name['ConfirmChangeEmailReq'] = _CONFIRMCHANGEEMAILREQ
DESCRIPTOR.message_types_by_name['ConfirmChangeEmailRes'] = _CONFIRMCHANGEEMAILRES
DESCRIPTOR.message_types_by_name['ContributorForm'] = _CONTRIBUTORFORM
DESCRIPTOR.enum_types_by_name['EmailConfirmationState'] = _EMAILCONFIRMATIONSTATE
DESCRIPTOR.enum_types_by_name['ContributeOption'] = _CONTRIBUTEOPTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SignupFlowReq = _reflection.GeneratedProtocolMessageType('SignupFlowReq', (_message.Message,), {
  'DESCRIPTOR' : _SIGNUPFLOWREQ,
  '__module__' : 'auth_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.auth.SignupFlowReq)
  })
_sym_db.RegisterMessage(SignupFlowReq)

SignupFlowRes = _reflection.GeneratedProtocolMessageType('SignupFlowRes', (_message.Message,), {
  'DESCRIPTOR' : _SIGNUPFLOWRES,
  '__module__' : 'auth_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.auth.SignupFlowRes)
  })
_sym_db.RegisterMessage(SignupFlowRes)

SignupBasic = _reflection.GeneratedProtocolMessageType('SignupBasic', (_message.Message,), {
  'DESCRIPTOR' : _SIGNUPBASIC,
  '__module__' : 'auth_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.auth.SignupBasic)
  })
_sym_db.RegisterMessage(SignupBasic)

SignupTokenInfoReq = _reflection.GeneratedProtocolMessageType('SignupTokenInfoReq', (_message.Message,), {
  'DESCRIPTOR' : _SIGNUPTOKENINFOREQ,
  '__module__' : 'auth_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.auth.SignupTokenInfoReq)
  })
_sym_db.RegisterMessage(SignupTokenInfoReq)

SignupAccount = _reflection.GeneratedProtocolMessageType('SignupAccount', (_message.Message,), {
  'DESCRIPTOR' : _SIGNUPACCOUNT,
  '__module__' : 'auth_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.auth.SignupAccount)
  })
_sym_db.RegisterMessage(SignupAccount)

UsernameValidReq = _reflection.GeneratedProtocolMessageType('UsernameValidReq', (_message.Message,), {
  'DESCRIPTOR' : _USERNAMEVALIDREQ,
  '__module__' : 'auth_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.auth.UsernameValidReq)
  })
_sym_db.RegisterMessage(UsernameValidReq)

UsernameValidRes = _reflection.GeneratedProtocolMessageType('UsernameValidRes', (_message.Message,), {
  'DESCRIPTOR' : _USERNAMEVALIDRES,
  '__module__' : 'auth_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.auth.UsernameValidRes)
  })
_sym_db.RegisterMessage(UsernameValidRes)

LoginReq = _reflection.GeneratedProtocolMessageType('LoginReq', (_message.Message,), {
  'DESCRIPTOR' : _LOGINREQ,
  '__module__' : 'auth_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.auth.LoginReq)
  })
_sym_db.RegisterMessage(LoginReq)

LoginRes = _reflection.GeneratedProtocolMessageType('LoginRes', (_message.Message,), {
  'DESCRIPTOR' : _LOGINRES,
  '__module__' : 'auth_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.auth.LoginRes)
  })
_sym_db.RegisterMessage(LoginRes)

CompleteTokenLoginReq = _reflection.GeneratedProtocolMessageType('CompleteTokenLoginReq', (_message.Message,), {
  'DESCRIPTOR' : _COMPLETETOKENLOGINREQ,
  '__module__' : 'auth_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.auth.CompleteTokenLoginReq)
  })
_sym_db.RegisterMessage(CompleteTokenLoginReq)

AuthReq = _reflection.GeneratedProtocolMessageType('AuthReq', (_message.Message,), {
  'DESCRIPTOR' : _AUTHREQ,
  '__module__' : 'auth_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.auth.AuthReq)
  })
_sym_db.RegisterMessage(AuthReq)

AuthRes = _reflection.GeneratedProtocolMessageType('AuthRes', (_message.Message,), {
  'DESCRIPTOR' : _AUTHRES,
  '__module__' : 'auth_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.auth.AuthRes)
  })
_sym_db.RegisterMessage(AuthRes)

ResetPasswordReq = _reflection.GeneratedProtocolMessageType('ResetPasswordReq', (_message.Message,), {
  'DESCRIPTOR' : _RESETPASSWORDREQ,
  '__module__' : 'auth_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.auth.ResetPasswordReq)
  })
_sym_db.RegisterMessage(ResetPasswordReq)

CompletePasswordResetReq = _reflection.GeneratedProtocolMessageType('CompletePasswordResetReq', (_message.Message,), {
  'DESCRIPTOR' : _COMPLETEPASSWORDRESETREQ,
  '__module__' : 'auth_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.auth.CompletePasswordResetReq)
  })
_sym_db.RegisterMessage(CompletePasswordResetReq)

ConfirmChangeEmailReq = _reflection.GeneratedProtocolMessageType('ConfirmChangeEmailReq', (_message.Message,), {
  'DESCRIPTOR' : _CONFIRMCHANGEEMAILREQ,
  '__module__' : 'auth_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.auth.ConfirmChangeEmailReq)
  })
_sym_db.RegisterMessage(ConfirmChangeEmailReq)

ConfirmChangeEmailRes = _reflection.GeneratedProtocolMessageType('ConfirmChangeEmailRes', (_message.Message,), {
  'DESCRIPTOR' : _CONFIRMCHANGEEMAILRES,
  '__module__' : 'auth_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.auth.ConfirmChangeEmailRes)
  })
_sym_db.RegisterMessage(ConfirmChangeEmailRes)

ContributorForm = _reflection.GeneratedProtocolMessageType('ContributorForm', (_message.Message,), {
  'DESCRIPTOR' : _CONTRIBUTORFORM,
  '__module__' : 'auth_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.auth.ContributorForm)
  })
_sym_db.RegisterMessage(ContributorForm)


_SIGNUPFLOWREQ.fields_by_name['flow_token']._options = None
_SIGNUPFLOWREQ.fields_by_name['email_token']._options = None
_SIGNUPFLOWRES.fields_by_name['flow_token']._options = None
_SIGNUPTOKENINFOREQ.fields_by_name['signup_token']._options = None
_SIGNUPACCOUNT.fields_by_name['password']._options = None
_COMPLETETOKENLOGINREQ.fields_by_name['login_token']._options = None
_AUTHREQ.fields_by_name['password']._options = None
_COMPLETEPASSWORDRESETREQ.fields_by_name['password_reset_token']._options = None
_CONFIRMCHANGEEMAILREQ.fields_by_name['change_email_token']._options = None

_AUTH = _descriptor.ServiceDescriptor(
  name='Auth',
  full_name='org.couchers.auth.Auth',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\210\265\030\001',
  create_key=_descriptor._internal_create_key,
  serialized_start=2176,
  serialized_end=2977,
  methods=[
  _descriptor.MethodDescriptor(
    name='SignupFlow',
    full_name='org.couchers.auth.Auth.SignupFlow',
    index=0,
    containing_service=None,
    input_type=_SIGNUPFLOWREQ,
    output_type=_SIGNUPFLOWRES,
    serialized_options=b'\202\323\344\223\002\021\"\014/auth/signup:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UsernameValid',
    full_name='org.couchers.auth.Auth.UsernameValid',
    index=1,
    containing_service=None,
    input_type=_USERNAMEVALIDREQ,
    output_type=_USERNAMEVALIDRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Login',
    full_name='org.couchers.auth.Auth.Login',
    index=2,
    containing_service=None,
    input_type=_LOGINREQ,
    output_type=_LOGINRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CompleteTokenLogin',
    full_name='org.couchers.auth.Auth.CompleteTokenLogin',
    index=3,
    containing_service=None,
    input_type=_COMPLETETOKENLOGINREQ,
    output_type=_AUTHRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Authenticate',
    full_name='org.couchers.auth.Auth.Authenticate',
    index=4,
    containing_service=None,
    input_type=_AUTHREQ,
    output_type=_AUTHRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Deauthenticate',
    full_name='org.couchers.auth.Auth.Deauthenticate',
    index=5,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ResetPassword',
    full_name='org.couchers.auth.Auth.ResetPassword',
    index=6,
    containing_service=None,
    input_type=_RESETPASSWORDREQ,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CompletePasswordReset',
    full_name='org.couchers.auth.Auth.CompletePasswordReset',
    index=7,
    containing_service=None,
    input_type=_COMPLETEPASSWORDRESETREQ,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ConfirmChangeEmail',
    full_name='org.couchers.auth.Auth.ConfirmChangeEmail',
    index=8,
    containing_service=None,
    input_type=_CONFIRMCHANGEEMAILREQ,
    output_type=_CONFIRMCHANGEEMAILRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_AUTH)

DESCRIPTOR.services_by_name['Auth'] = _AUTH

# @@protoc_insertion_point(module_scope)



from pathlib import Path

import grpc

from couchers.services import get_all_stubs

DEFAULT_SERVER_ADDRESS = "api.couchers.org:8443"

parent_folder = Path(__file__).parent

version = (parent_folder / "version").read_text().strip()


def get_client(api_key, server_address=DEFAULT_SERVER_ADDRESS, disable_tls=False):
    """
    Given an API key returns a client object.

    `disable_tls` connects to the server insecurely. This only works on localhost, thanks to gRPC.

    Returns a new class with attributes corresponding to each stub, with attributes such as `account`, corresponding to
    an account gRPC stub.
    """
    if disable_tls:
        creds = grpc.local_channel_credentials()
    else:
        creds = grpc.ssl_channel_credentials()

    creds = grpc.composite_channel_credentials(creds, grpc.access_token_call_credentials(api_key))

    channel = grpc.secure_channel(server_address, creds)
    stubs = get_all_stubs(channel)
    return type("__Client", (), stubs)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: account.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from . import annotations_pb2 as annotations__pb2
from . import auth_pb2 as auth__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='account.proto',
  package='org.couchers.api.account',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\raccount.proto\x12\x18org.couchers.api.account\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x11\x61nnotations.proto\x1a\nauth.proto\"\x81\x02\n\x11GetAccountInfoRes\x12M\n\x0clogin_method\x18\x01 \x01(\x0e\x32\x37.org.couchers.api.account.GetAccountInfoRes.LoginMethod\x12\x14\n\x0chas_password\x18\x02 \x01(\x08\x12\x10\n\x08username\x18\x07 \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\x12\x18\n\x10profile_complete\x18\x04 \x01(\x08\x12\r\n\x05phone\x18\x05 \x01(\t\x12\x10\n\x08timezone\x18\x06 \x01(\t\"+\n\x0bLoginMethod\x12\x0e\n\nMAGIC_LINK\x10\x00\x12\x0c\n\x08PASSWORD\x10\x01\"\x87\x01\n\x11\x43hangePasswordReq\x12\x38\n\x0cold_password\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x04\x80\xb5\x18\x01\x12\x38\n\x0cnew_password\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x04\x80\xb5\x18\x01\"Y\n\x0e\x43hangeEmailReq\x12\x34\n\x08password\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x04\x80\xb5\x18\x01\x12\x11\n\tnew_email\x18\x02 \x01(\t\"<\n\x19GetContributorFormInfoRes\x12\x1f\n\x17\x66illed_contributor_form\x18\x01 \x01(\x08\"V\n\x16\x46illContributorFormReq\x12<\n\x10\x63ontributor_form\x18\x01 \x01(\x0b\x32\".org.couchers.auth.ContributorForm\"\x1f\n\x0e\x43hangePhoneReq\x12\r\n\x05phone\x18\x01 \x01(\t\"%\n\x0eVerifyPhoneReq\x12\x13\n\x05token\x18\x01 \x01(\tB\x04\x80\xb5\x18\x01\x32\x86\x05\n\x07\x41\x63\x63ount\x12W\n\x0eGetAccountInfo\x12\x16.google.protobuf.Empty\x1a+.org.couchers.api.account.GetAccountInfoRes\"\x00\x12W\n\x0e\x43hangePassword\x12+.org.couchers.api.account.ChangePasswordReq\x1a\x16.google.protobuf.Empty\"\x00\x12Q\n\x0b\x43hangeEmail\x12(.org.couchers.api.account.ChangeEmailReq\x1a\x16.google.protobuf.Empty\"\x00\x12g\n\x16GetContributorFormInfo\x12\x16.google.protobuf.Empty\x1a\x33.org.couchers.api.account.GetContributorFormInfoRes\"\x00\x12\x61\n\x13\x46illContributorForm\x12\x30.org.couchers.api.account.FillContributorFormReq\x1a\x16.google.protobuf.Empty\"\x00\x12Q\n\x0b\x43hangePhone\x12(.org.couchers.api.account.ChangePhoneReq\x1a\x16.google.protobuf.Empty\"\x00\x12Q\n\x0bVerifyPhone\x12(.org.couchers.api.account.VerifyPhoneReq\x1a\x16.google.protobuf.Empty\"\x00\x1a\x04\x88\xb5\x18\x03\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,annotations__pb2.DESCRIPTOR,auth__pb2.DESCRIPTOR,])



_GETACCOUNTINFORES_LOGINMETHOD = _descriptor.EnumDescriptor(
  name='LoginMethod',
  full_name='org.couchers.api.account.GetAccountInfoRes.LoginMethod',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MAGIC_LINK', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PASSWORD', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=350,
  serialized_end=393,
)
_sym_db.RegisterEnumDescriptor(_GETACCOUNTINFORES_LOGINMETHOD)


_GETACCOUNTINFORES = _descriptor.Descriptor(
  name='GetAccountInfoRes',
  full_name='org.couchers.api.account.GetAccountInfoRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='login_method', full_name='org.couchers.api.account.GetAccountInfoRes.login_method', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='has_password', full_name='org.couchers.api.account.GetAccountInfoRes.has_password', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='username', full_name='org.couchers.api.account.GetAccountInfoRes.username', index=2,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='email', full_name='org.couchers.api.account.GetAccountInfoRes.email', index=3,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='profile_complete', full_name='org.couchers.api.account.GetAccountInfoRes.profile_complete', index=4,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='phone', full_name='org.couchers.api.account.GetAccountInfoRes.phone', index=5,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timezone', full_name='org.couchers.api.account.GetAccountInfoRes.timezone', index=6,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GETACCOUNTINFORES_LOGINMETHOD,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=136,
  serialized_end=393,
)


_CHANGEPASSWORDREQ = _descriptor.Descriptor(
  name='ChangePasswordReq',
  full_name='org.couchers.api.account.ChangePasswordReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='old_password', full_name='org.couchers.api.account.ChangePasswordReq.old_password', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\200\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_password', full_name='org.couchers.api.account.ChangePasswordReq.new_password', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\200\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=396,
  serialized_end=531,
)


_CHANGEEMAILREQ = _descriptor.Descriptor(
  name='ChangeEmailReq',
  full_name='org.couchers.api.account.ChangeEmailReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='password', full_name='org.couchers.api.account.ChangeEmailReq.password', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\200\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_email', full_name='org.couchers.api.account.ChangeEmailReq.new_email', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=533,
  serialized_end=622,
)


_GETCONTRIBUTORFORMINFORES = _descriptor.Descriptor(
  name='GetContributorFormInfoRes',
  full_name='org.couchers.api.account.GetContributorFormInfoRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filled_contributor_form', full_name='org.couchers.api.account.GetContributorFormInfoRes.filled_contributor_form', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=624,
  serialized_end=684,
)


_FILLCONTRIBUTORFORMREQ = _descriptor.Descriptor(
  name='FillContributorFormReq',
  full_name='org.couchers.api.account.FillContributorFormReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contributor_form', full_name='org.couchers.api.account.FillContributorFormReq.contributor_form', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=686,
  serialized_end=772,
)


_CHANGEPHONEREQ = _descriptor.Descriptor(
  name='ChangePhoneReq',
  full_name='org.couchers.api.account.ChangePhoneReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='phone', full_name='org.couchers.api.account.ChangePhoneReq.phone', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=774,
  serialized_end=805,
)


_VERIFYPHONEREQ = _descriptor.Descriptor(
  name='VerifyPhoneReq',
  full_name='org.couchers.api.account.VerifyPhoneReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='org.couchers.api.account.VerifyPhoneReq.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\200\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=807,
  serialized_end=844,
)

_GETACCOUNTINFORES.fields_by_name['login_method'].enum_type = _GETACCOUNTINFORES_LOGINMETHOD
_GETACCOUNTINFORES_LOGINMETHOD.containing_type = _GETACCOUNTINFORES
_CHANGEPASSWORDREQ.fields_by_name['old_password'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CHANGEPASSWORDREQ.fields_by_name['new_password'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CHANGEEMAILREQ.fields_by_name['password'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_FILLCONTRIBUTORFORMREQ.fields_by_name['contributor_form'].message_type = auth__pb2._CONTRIBUTORFORM
DESCRIPTOR.message_types_by_name['GetAccountInfoRes'] = _GETACCOUNTINFORES
DESCRIPTOR.message_types_by_name['ChangePasswordReq'] = _CHANGEPASSWORDREQ
DESCRIPTOR.message_types_by_name['ChangeEmailReq'] = _CHANGEEMAILREQ
DESCRIPTOR.message_types_by_name['GetContributorFormInfoRes'] = _GETCONTRIBUTORFORMINFORES
DESCRIPTOR.message_types_by_name['FillContributorFormReq'] = _FILLCONTRIBUTORFORMREQ
DESCRIPTOR.message_types_by_name['ChangePhoneReq'] = _CHANGEPHONEREQ
DESCRIPTOR.message_types_by_name['VerifyPhoneReq'] = _VERIFYPHONEREQ
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetAccountInfoRes = _reflection.GeneratedProtocolMessageType('GetAccountInfoRes', (_message.Message,), {
  'DESCRIPTOR' : _GETACCOUNTINFORES,
  '__module__' : 'account_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.account.GetAccountInfoRes)
  })
_sym_db.RegisterMessage(GetAccountInfoRes)

ChangePasswordReq = _reflection.GeneratedProtocolMessageType('ChangePasswordReq', (_message.Message,), {
  'DESCRIPTOR' : _CHANGEPASSWORDREQ,
  '__module__' : 'account_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.account.ChangePasswordReq)
  })
_sym_db.RegisterMessage(ChangePasswordReq)

ChangeEmailReq = _reflection.GeneratedProtocolMessageType('ChangeEmailReq', (_message.Message,), {
  'DESCRIPTOR' : _CHANGEEMAILREQ,
  '__module__' : 'account_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.account.ChangeEmailReq)
  })
_sym_db.RegisterMessage(ChangeEmailReq)

GetContributorFormInfoRes = _reflection.GeneratedProtocolMessageType('GetContributorFormInfoRes', (_message.Message,), {
  'DESCRIPTOR' : _GETCONTRIBUTORFORMINFORES,
  '__module__' : 'account_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.account.GetContributorFormInfoRes)
  })
_sym_db.RegisterMessage(GetContributorFormInfoRes)

FillContributorFormReq = _reflection.GeneratedProtocolMessageType('FillContributorFormReq', (_message.Message,), {
  'DESCRIPTOR' : _FILLCONTRIBUTORFORMREQ,
  '__module__' : 'account_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.account.FillContributorFormReq)
  })
_sym_db.RegisterMessage(FillContributorFormReq)

ChangePhoneReq = _reflection.GeneratedProtocolMessageType('ChangePhoneReq', (_message.Message,), {
  'DESCRIPTOR' : _CHANGEPHONEREQ,
  '__module__' : 'account_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.account.ChangePhoneReq)
  })
_sym_db.RegisterMessage(ChangePhoneReq)

VerifyPhoneReq = _reflection.GeneratedProtocolMessageType('VerifyPhoneReq', (_message.Message,), {
  'DESCRIPTOR' : _VERIFYPHONEREQ,
  '__module__' : 'account_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.account.VerifyPhoneReq)
  })
_sym_db.RegisterMessage(VerifyPhoneReq)


_CHANGEPASSWORDREQ.fields_by_name['old_password']._options = None
_CHANGEPASSWORDREQ.fields_by_name['new_password']._options = None
_CHANGEEMAILREQ.fields_by_name['password']._options = None
_VERIFYPHONEREQ.fields_by_name['token']._options = None

_ACCOUNT = _descriptor.ServiceDescriptor(
  name='Account',
  full_name='org.couchers.api.account.Account',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\210\265\030\003',
  create_key=_descriptor._internal_create_key,
  serialized_start=847,
  serialized_end=1493,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetAccountInfo',
    full_name='org.couchers.api.account.Account.GetAccountInfo',
    index=0,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_GETACCOUNTINFORES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ChangePassword',
    full_name='org.couchers.api.account.Account.ChangePassword',
    index=1,
    containing_service=None,
    input_type=_CHANGEPASSWORDREQ,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ChangeEmail',
    full_name='org.couchers.api.account.Account.ChangeEmail',
    index=2,
    containing_service=None,
    input_type=_CHANGEEMAILREQ,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetContributorFormInfo',
    full_name='org.couchers.api.account.Account.GetContributorFormInfo',
    index=3,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_GETCONTRIBUTORFORMINFORES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FillContributorForm',
    full_name='org.couchers.api.account.Account.FillContributorForm',
    index=4,
    containing_service=None,
    input_type=_FILLCONTRIBUTORFORMREQ,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ChangePhone',
    full_name='org.couchers.api.account.Account.ChangePhone',
    index=5,
    containing_service=None,
    input_type=_CHANGEPHONEREQ,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='VerifyPhone',
    full_name='org.couchers.api.account.Account.VerifyPhone',
    index=6,
    containing_service=None,
    input_type=_VERIFYPHONEREQ,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_ACCOUNT)

DESCRIPTOR.services_by_name['Account'] = _ACCOUNT

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: requests.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import annotations_pb2 as annotations__pb2
from . import conversations_pb2 as conversations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='requests.proto',
  package='org.couchers.api.requests',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0erequests.proto\x12\x19org.couchers.api.requests\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x11\x61nnotations.proto\x1a\x13\x63onversations.proto\"^\n\x14\x43reateHostRequestReq\x12\x14\n\x0chost_user_id\x18\x01 \x01(\x03\x12\x11\n\tfrom_date\x18\x02 \x01(\t\x12\x0f\n\x07to_date\x18\x03 \x01(\t\x12\x0c\n\x04text\x18\x04 \x01(\t\"\xc7\x02\n\x0bHostRequest\x12\x17\n\x0fhost_request_id\x18\x01 \x01(\x03\x12\x16\n\x0esurfer_user_id\x18\x02 \x01(\x03\x12\x14\n\x0chost_user_id\x18\x03 \x01(\x03\x12\x41\n\x06status\x18\x04 \x01(\x0e\x32\x31.org.couchers.api.conversations.HostRequestStatus\x12+\n\x07\x63reated\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x11\n\tfrom_date\x18\x06 \x01(\t\x12\x0f\n\x07to_date\x18\x07 \x01(\t\x12\x1c\n\x14last_seen_message_id\x18\x08 \x01(\x03\x12?\n\x0elatest_message\x18\t \x01(\x0b\x32\'.org.couchers.api.conversations.Message\",\n\x11GetHostRequestReq\x12\x17\n\x0fhost_request_id\x18\x01 \x01(\x03\"/\n\x14\x43reateHostRequestRes\x12\x17\n\x0fhost_request_id\x18\x01 \x01(\x03\"\x81\x01\n\x15RespondHostRequestReq\x12\x17\n\x0fhost_request_id\x18\x01 \x01(\x03\x12\x41\n\x06status\x18\x02 \x01(\x0e\x32\x31.org.couchers.api.conversations.HostRequestStatus\x12\x0c\n\x04text\x18\x03 \x01(\t\"}\n\x13ListHostRequestsReq\x12\x17\n\x0flast_request_id\x18\x01 \x01(\x03\x12\x0e\n\x06number\x18\x02 \x01(\r\x12\x13\n\x0bonly_active\x18\x03 \x01(\x08\x12\x11\n\tonly_sent\x18\x04 \x01(\x08\x12\x15\n\ronly_received\x18\x05 \x01(\x08\"~\n\x13ListHostRequestsRes\x12=\n\rhost_requests\x18\x01 \x03(\x0b\x32&.org.couchers.api.requests.HostRequest\x12\x17\n\x0flast_request_id\x18\x02 \x01(\x03\x12\x0f\n\x07no_more\x18\x03 \x01(\x08\"]\n\x19GetHostRequestMessagesReq\x12\x17\n\x0fhost_request_id\x18\x01 \x01(\x03\x12\x17\n\x0flast_message_id\x18\x02 \x01(\x03\x12\x0e\n\x06number\x18\x03 \x01(\r\"\x80\x01\n\x19GetHostRequestMessagesRes\x12\x39\n\x08messages\x18\x01 \x03(\x0b\x32\'.org.couchers.api.conversations.Message\x12\x17\n\x0flast_message_id\x18\x04 \x01(\x03\x12\x0f\n\x07no_more\x18\x05 \x01(\x08\"B\n\x19SendHostRequestMessageReq\x12\x17\n\x0fhost_request_id\x18\x01 \x01(\x03\x12\x0c\n\x04text\x18\x02 \x01(\t\"o\n\x18GetHostRequestUpdatesReq\x12\x19\n\x11newest_message_id\x18\x01 \x01(\x03\x12\x0e\n\x06number\x18\x02 \x01(\r\x12\x11\n\tonly_sent\x18\x03 \x01(\x08\x12\x15\n\ronly_received\x18\x04 \x01(\x08\"\xa9\x01\n\x11HostRequestUpdate\x12\x17\n\x0fhost_request_id\x18\x01 \x01(\x03\x12\x38\n\x07message\x18\x02 \x01(\x0b\x32\'.org.couchers.api.conversations.Message\x12\x41\n\x06status\x18\x03 \x01(\x0e\x32\x31.org.couchers.api.conversations.HostRequestStatus\"j\n\x18GetHostRequestUpdatesRes\x12=\n\x07updates\x18\x01 \x03(\x0b\x32,.org.couchers.api.requests.HostRequestUpdate\x12\x0f\n\x07no_more\x18\x02 \x01(\x08\"S\n\x1aMarkLastSeenHostRequestReq\x12\x17\n\x0fhost_request_id\x18\x01 \x01(\x03\x12\x1c\n\x14last_seen_message_id\x18\x02 \x01(\x03\x32\xa0\x07\n\x08Requests\x12u\n\x11\x43reateHostRequest\x12/.org.couchers.api.requests.CreateHostRequestReq\x1a/.org.couchers.api.requests.CreateHostRequestRes\x12\x66\n\x0eGetHostRequest\x12,.org.couchers.api.requests.GetHostRequestReq\x1a&.org.couchers.api.requests.HostRequest\x12^\n\x12RespondHostRequest\x12\x30.org.couchers.api.requests.RespondHostRequestReq\x1a\x16.google.protobuf.Empty\x12r\n\x10ListHostRequests\x12..org.couchers.api.requests.ListHostRequestsReq\x1a..org.couchers.api.requests.ListHostRequestsRes\x12\x84\x01\n\x16GetHostRequestMessages\x12\x34.org.couchers.api.requests.GetHostRequestMessagesReq\x1a\x34.org.couchers.api.requests.GetHostRequestMessagesRes\x12\x66\n\x16SendHostRequestMessage\x12\x34.org.couchers.api.requests.SendHostRequestMessageReq\x1a\x16.google.protobuf.Empty\x12\x81\x01\n\x15GetHostRequestUpdates\x12\x33.org.couchers.api.requests.GetHostRequestUpdatesReq\x1a\x33.org.couchers.api.requests.GetHostRequestUpdatesRes\x12h\n\x17MarkLastSeenHostRequest\x12\x35.org.couchers.api.requests.MarkLastSeenHostRequestReq\x1a\x16.google.protobuf.Empty\x1a\x04\x88\xb5\x18\x03\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,annotations__pb2.DESCRIPTOR,conversations__pb2.DESCRIPTOR,])




_CREATEHOSTREQUESTREQ = _descriptor.Descriptor(
  name='CreateHostRequestReq',
  full_name='org.couchers.api.requests.CreateHostRequestReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='host_user_id', full_name='org.couchers.api.requests.CreateHostRequestReq.host_user_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='from_date', full_name='org.couchers.api.requests.CreateHostRequestReq.from_date', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='to_date', full_name='org.couchers.api.requests.CreateHostRequestReq.to_date', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text', full_name='org.couchers.api.requests.CreateHostRequestReq.text', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=147,
  serialized_end=241,
)


_HOSTREQUEST = _descriptor.Descriptor(
  name='HostRequest',
  full_name='org.couchers.api.requests.HostRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='host_request_id', full_name='org.couchers.api.requests.HostRequest.host_request_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='surfer_user_id', full_name='org.couchers.api.requests.HostRequest.surfer_user_id', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='host_user_id', full_name='org.couchers.api.requests.HostRequest.host_user_id', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='org.couchers.api.requests.HostRequest.status', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created', full_name='org.couchers.api.requests.HostRequest.created', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='from_date', full_name='org.couchers.api.requests.HostRequest.from_date', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='to_date', full_name='org.couchers.api.requests.HostRequest.to_date', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_seen_message_id', full_name='org.couchers.api.requests.HostRequest.last_seen_message_id', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='latest_message', full_name='org.couchers.api.requests.HostRequest.latest_message', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=244,
  serialized_end=571,
)


_GETHOSTREQUESTREQ = _descriptor.Descriptor(
  name='GetHostRequestReq',
  full_name='org.couchers.api.requests.GetHostRequestReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='host_request_id', full_name='org.couchers.api.requests.GetHostRequestReq.host_request_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=573,
  serialized_end=617,
)


_CREATEHOSTREQUESTRES = _descriptor.Descriptor(
  name='CreateHostRequestRes',
  full_name='org.couchers.api.requests.CreateHostRequestRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='host_request_id', full_name='org.couchers.api.requests.CreateHostRequestRes.host_request_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=619,
  serialized_end=666,
)


_RESPONDHOSTREQUESTREQ = _descriptor.Descriptor(
  name='RespondHostRequestReq',
  full_name='org.couchers.api.requests.RespondHostRequestReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='host_request_id', full_name='org.couchers.api.requests.RespondHostRequestReq.host_request_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='org.couchers.api.requests.RespondHostRequestReq.status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text', full_name='org.couchers.api.requests.RespondHostRequestReq.text', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=669,
  serialized_end=798,
)


_LISTHOSTREQUESTSREQ = _descriptor.Descriptor(
  name='ListHostRequestsReq',
  full_name='org.couchers.api.requests.ListHostRequestsReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='last_request_id', full_name='org.couchers.api.requests.ListHostRequestsReq.last_request_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='number', full_name='org.couchers.api.requests.ListHostRequestsReq.number', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='only_active', full_name='org.couchers.api.requests.ListHostRequestsReq.only_active', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='only_sent', full_name='org.couchers.api.requests.ListHostRequestsReq.only_sent', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='only_received', full_name='org.couchers.api.requests.ListHostRequestsReq.only_received', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=800,
  serialized_end=925,
)


_LISTHOSTREQUESTSRES = _descriptor.Descriptor(
  name='ListHostRequestsRes',
  full_name='org.couchers.api.requests.ListHostRequestsRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='host_requests', full_name='org.couchers.api.requests.ListHostRequestsRes.host_requests', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_request_id', full_name='org.couchers.api.requests.ListHostRequestsRes.last_request_id', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='no_more', full_name='org.couchers.api.requests.ListHostRequestsRes.no_more', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=927,
  serialized_end=1053,
)


_GETHOSTREQUESTMESSAGESREQ = _descriptor.Descriptor(
  name='GetHostRequestMessagesReq',
  full_name='org.couchers.api.requests.GetHostRequestMessagesReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='host_request_id', full_name='org.couchers.api.requests.GetHostRequestMessagesReq.host_request_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_message_id', full_name='org.couchers.api.requests.GetHostRequestMessagesReq.last_message_id', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='number', full_name='org.couchers.api.requests.GetHostRequestMessagesReq.number', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1055,
  serialized_end=1148,
)


_GETHOSTREQUESTMESSAGESRES = _descriptor.Descriptor(
  name='GetHostRequestMessagesRes',
  full_name='org.couchers.api.requests.GetHostRequestMessagesRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='messages', full_name='org.couchers.api.requests.GetHostRequestMessagesRes.messages', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_message_id', full_name='org.couchers.api.requests.GetHostRequestMessagesRes.last_message_id', index=1,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='no_more', full_name='org.couchers.api.requests.GetHostRequestMessagesRes.no_more', index=2,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1151,
  serialized_end=1279,
)


_SENDHOSTREQUESTMESSAGEREQ = _descriptor.Descriptor(
  name='SendHostRequestMessageReq',
  full_name='org.couchers.api.requests.SendHostRequestMessageReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='host_request_id', full_name='org.couchers.api.requests.SendHostRequestMessageReq.host_request_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text', full_name='org.couchers.api.requests.SendHostRequestMessageReq.text', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1281,
  serialized_end=1347,
)


_GETHOSTREQUESTUPDATESREQ = _descriptor.Descriptor(
  name='GetHostRequestUpdatesReq',
  full_name='org.couchers.api.requests.GetHostRequestUpdatesReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='newest_message_id', full_name='org.couchers.api.requests.GetHostRequestUpdatesReq.newest_message_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='number', full_name='org.couchers.api.requests.GetHostRequestUpdatesReq.number', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='only_sent', full_name='org.couchers.api.requests.GetHostRequestUpdatesReq.only_sent', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='only_received', full_name='org.couchers.api.requests.GetHostRequestUpdatesReq.only_received', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1349,
  serialized_end=1460,
)


_HOSTREQUESTUPDATE = _descriptor.Descriptor(
  name='HostRequestUpdate',
  full_name='org.couchers.api.requests.HostRequestUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='host_request_id', full_name='org.couchers.api.requests.HostRequestUpdate.host_request_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='org.couchers.api.requests.HostRequestUpdate.message', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='org.couchers.api.requests.HostRequestUpdate.status', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1463,
  serialized_end=1632,
)


_GETHOSTREQUESTUPDATESRES = _descriptor.Descriptor(
  name='GetHostRequestUpdatesRes',
  full_name='org.couchers.api.requests.GetHostRequestUpdatesRes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='updates', full_name='org.couchers.api.requests.GetHostRequestUpdatesRes.updates', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='no_more', full_name='org.couchers.api.requests.GetHostRequestUpdatesRes.no_more', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1634,
  serialized_end=1740,
)


_MARKLASTSEENHOSTREQUESTREQ = _descriptor.Descriptor(
  name='MarkLastSeenHostRequestReq',
  full_name='org.couchers.api.requests.MarkLastSeenHostRequestReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='host_request_id', full_name='org.couchers.api.requests.MarkLastSeenHostRequestReq.host_request_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_seen_message_id', full_name='org.couchers.api.requests.MarkLastSeenHostRequestReq.last_seen_message_id', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1742,
  serialized_end=1825,
)

_HOSTREQUEST.fields_by_name['status'].enum_type = conversations__pb2._HOSTREQUESTSTATUS
_HOSTREQUEST.fields_by_name['created'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_HOSTREQUEST.fields_by_name['latest_message'].message_type = conversations__pb2._MESSAGE
_RESPONDHOSTREQUESTREQ.fields_by_name['status'].enum_type = conversations__pb2._HOSTREQUESTSTATUS
_LISTHOSTREQUESTSRES.fields_by_name['host_requests'].message_type = _HOSTREQUEST
_GETHOSTREQUESTMESSAGESRES.fields_by_name['messages'].message_type = conversations__pb2._MESSAGE
_HOSTREQUESTUPDATE.fields_by_name['message'].message_type = conversations__pb2._MESSAGE
_HOSTREQUESTUPDATE.fields_by_name['status'].enum_type = conversations__pb2._HOSTREQUESTSTATUS
_GETHOSTREQUESTUPDATESRES.fields_by_name['updates'].message_type = _HOSTREQUESTUPDATE
DESCRIPTOR.message_types_by_name['CreateHostRequestReq'] = _CREATEHOSTREQUESTREQ
DESCRIPTOR.message_types_by_name['HostRequest'] = _HOSTREQUEST
DESCRIPTOR.message_types_by_name['GetHostRequestReq'] = _GETHOSTREQUESTREQ
DESCRIPTOR.message_types_by_name['CreateHostRequestRes'] = _CREATEHOSTREQUESTRES
DESCRIPTOR.message_types_by_name['RespondHostRequestReq'] = _RESPONDHOSTREQUESTREQ
DESCRIPTOR.message_types_by_name['ListHostRequestsReq'] = _LISTHOSTREQUESTSREQ
DESCRIPTOR.message_types_by_name['ListHostRequestsRes'] = _LISTHOSTREQUESTSRES
DESCRIPTOR.message_types_by_name['GetHostRequestMessagesReq'] = _GETHOSTREQUESTMESSAGESREQ
DESCRIPTOR.message_types_by_name['GetHostRequestMessagesRes'] = _GETHOSTREQUESTMESSAGESRES
DESCRIPTOR.message_types_by_name['SendHostRequestMessageReq'] = _SENDHOSTREQUESTMESSAGEREQ
DESCRIPTOR.message_types_by_name['GetHostRequestUpdatesReq'] = _GETHOSTREQUESTUPDATESREQ
DESCRIPTOR.message_types_by_name['HostRequestUpdate'] = _HOSTREQUESTUPDATE
DESCRIPTOR.message_types_by_name['GetHostRequestUpdatesRes'] = _GETHOSTREQUESTUPDATESRES
DESCRIPTOR.message_types_by_name['MarkLastSeenHostRequestReq'] = _MARKLASTSEENHOSTREQUESTREQ
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateHostRequestReq = _reflection.GeneratedProtocolMessageType('CreateHostRequestReq', (_message.Message,), {
  'DESCRIPTOR' : _CREATEHOSTREQUESTREQ,
  '__module__' : 'requests_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.requests.CreateHostRequestReq)
  })
_sym_db.RegisterMessage(CreateHostRequestReq)

HostRequest = _reflection.GeneratedProtocolMessageType('HostRequest', (_message.Message,), {
  'DESCRIPTOR' : _HOSTREQUEST,
  '__module__' : 'requests_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.requests.HostRequest)
  })
_sym_db.RegisterMessage(HostRequest)

GetHostRequestReq = _reflection.GeneratedProtocolMessageType('GetHostRequestReq', (_message.Message,), {
  'DESCRIPTOR' : _GETHOSTREQUESTREQ,
  '__module__' : 'requests_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.requests.GetHostRequestReq)
  })
_sym_db.RegisterMessage(GetHostRequestReq)

CreateHostRequestRes = _reflection.GeneratedProtocolMessageType('CreateHostRequestRes', (_message.Message,), {
  'DESCRIPTOR' : _CREATEHOSTREQUESTRES,
  '__module__' : 'requests_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.requests.CreateHostRequestRes)
  })
_sym_db.RegisterMessage(CreateHostRequestRes)

RespondHostRequestReq = _reflection.GeneratedProtocolMessageType('RespondHostRequestReq', (_message.Message,), {
  'DESCRIPTOR' : _RESPONDHOSTREQUESTREQ,
  '__module__' : 'requests_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.requests.RespondHostRequestReq)
  })
_sym_db.RegisterMessage(RespondHostRequestReq)

ListHostRequestsReq = _reflection.GeneratedProtocolMessageType('ListHostRequestsReq', (_message.Message,), {
  'DESCRIPTOR' : _LISTHOSTREQUESTSREQ,
  '__module__' : 'requests_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.requests.ListHostRequestsReq)
  })
_sym_db.RegisterMessage(ListHostRequestsReq)

ListHostRequestsRes = _reflection.GeneratedProtocolMessageType('ListHostRequestsRes', (_message.Message,), {
  'DESCRIPTOR' : _LISTHOSTREQUESTSRES,
  '__module__' : 'requests_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.requests.ListHostRequestsRes)
  })
_sym_db.RegisterMessage(ListHostRequestsRes)

GetHostRequestMessagesReq = _reflection.GeneratedProtocolMessageType('GetHostRequestMessagesReq', (_message.Message,), {
  'DESCRIPTOR' : _GETHOSTREQUESTMESSAGESREQ,
  '__module__' : 'requests_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.requests.GetHostRequestMessagesReq)
  })
_sym_db.RegisterMessage(GetHostRequestMessagesReq)

GetHostRequestMessagesRes = _reflection.GeneratedProtocolMessageType('GetHostRequestMessagesRes', (_message.Message,), {
  'DESCRIPTOR' : _GETHOSTREQUESTMESSAGESRES,
  '__module__' : 'requests_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.requests.GetHostRequestMessagesRes)
  })
_sym_db.RegisterMessage(GetHostRequestMessagesRes)

SendHostRequestMessageReq = _reflection.GeneratedProtocolMessageType('SendHostRequestMessageReq', (_message.Message,), {
  'DESCRIPTOR' : _SENDHOSTREQUESTMESSAGEREQ,
  '__module__' : 'requests_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.requests.SendHostRequestMessageReq)
  })
_sym_db.RegisterMessage(SendHostRequestMessageReq)

GetHostRequestUpdatesReq = _reflection.GeneratedProtocolMessageType('GetHostRequestUpdatesReq', (_message.Message,), {
  'DESCRIPTOR' : _GETHOSTREQUESTUPDATESREQ,
  '__module__' : 'requests_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.requests.GetHostRequestUpdatesReq)
  })
_sym_db.RegisterMessage(GetHostRequestUpdatesReq)

HostRequestUpdate = _reflection.GeneratedProtocolMessageType('HostRequestUpdate', (_message.Message,), {
  'DESCRIPTOR' : _HOSTREQUESTUPDATE,
  '__module__' : 'requests_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.requests.HostRequestUpdate)
  })
_sym_db.RegisterMessage(HostRequestUpdate)

GetHostRequestUpdatesRes = _reflection.GeneratedProtocolMessageType('GetHostRequestUpdatesRes', (_message.Message,), {
  'DESCRIPTOR' : _GETHOSTREQUESTUPDATESRES,
  '__module__' : 'requests_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.requests.GetHostRequestUpdatesRes)
  })
_sym_db.RegisterMessage(GetHostRequestUpdatesRes)

MarkLastSeenHostRequestReq = _reflection.GeneratedProtocolMessageType('MarkLastSeenHostRequestReq', (_message.Message,), {
  'DESCRIPTOR' : _MARKLASTSEENHOSTREQUESTREQ,
  '__module__' : 'requests_pb2'
  # @@protoc_insertion_point(class_scope:org.couchers.api.requests.MarkLastSeenHostRequestReq)
  })
_sym_db.RegisterMessage(MarkLastSeenHostRequestReq)



_REQUESTS = _descriptor.ServiceDescriptor(
  name='Requests',
  full_name='org.couchers.api.requests.Requests',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\210\265\030\003',
  create_key=_descriptor._internal_create_key,
  serialized_start=1828,
  serialized_end=2756,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateHostRequest',
    full_name='org.couchers.api.requests.Requests.CreateHostRequest',
    index=0,
    containing_service=None,
    input_type=_CREATEHOSTREQUESTREQ,
    output_type=_CREATEHOSTREQUESTRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetHostRequest',
    full_name='org.couchers.api.requests.Requests.GetHostRequest',
    index=1,
    containing_service=None,
    input_type=_GETHOSTREQUESTREQ,
    output_type=_HOSTREQUEST,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RespondHostRequest',
    full_name='org.couchers.api.requests.Requests.RespondHostRequest',
    index=2,
    containing_service=None,
    input_type=_RESPONDHOSTREQUESTREQ,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListHostRequests',
    full_name='org.couchers.api.requests.Requests.ListHostRequests',
    index=3,
    containing_service=None,
    input_type=_LISTHOSTREQUESTSREQ,
    output_type=_LISTHOSTREQUESTSRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetHostRequestMessages',
    full_name='org.couchers.api.requests.Requests.GetHostRequestMessages',
    index=4,
    containing_service=None,
    input_type=_GETHOSTREQUESTMESSAGESREQ,
    output_type=_GETHOSTREQUESTMESSAGESRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SendHostRequestMessage',
    full_name='org.couchers.api.requests.Requests.SendHostRequestMessage',
    index=5,
    containing_service=None,
    input_type=_SENDHOSTREQUESTMESSAGEREQ,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetHostRequestUpdates',
    full_name='org.couchers.api.requests.Requests.GetHostRequestUpdates',
    index=6,
    containing_service=None,
    input_type=_GETHOSTREQUESTUPDATESREQ,
    output_type=_GETHOSTREQUESTUPDATESRES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='MarkLastSeenHostRequest',
    full_name='org.couchers.api.requests.Requests.MarkLastSeenHostRequest',
    index=7,
    containing_service=None,
    input_type=_MARKLASTSEENHOSTREQUESTREQ,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_REQUESTS)

DESCRIPTOR.services_by_name['Requests'] = _REQUESTS

# @@protoc_insertion_point(module_scope)
